@@ -1,6 +1,7 @@
 import grpc
 import jwt  # pip install pyJWT, ATTENTION, no pip install jwt!!
 import time
+import os
 from retry import retry
 
 from . import auth_pb2
@@ -43,12 +44,18 @@ def is_recoverable(exception):
            grpc.StatusCode.PERMISSION_DENIED != exception.code()
 
 
+def connect():
+    connectTo(os.environ["BATCHX_ENDPOINT"], os.environ["BATCHX_TOKEN"], True);
+
 @retry(RecoverableException, delay=CALL_DELAY, backoff=CALL_BACKOFF, max_delay=CALL_MAX_DELAY, tries=MAX_TRIES)
-def connect(endpoint, token):
+def connectTo(endpoint, token, secure):
     global channel, bx_token, bx_endpoint
     if channel is None:
         try:
-            channel = grpc.secure_channel(endpoint, grpc.ssl_channel_credentials())
+            if secure:
+                channel = grpc.secure_channel(endpoint, grpc.ssl_channel_credentials())
+            else:
+                channel = grpc.insecure_channel(endpoint)
             grpc.channel_ready_future(channel).result(CHANNEL_TIMEOUT)
         except grpc.FutureTimeoutError as exc:
             channel = None
